@@ -61,7 +61,7 @@ struct XorrisO;
 */
 #define Xorriso_header_version_majoR  0
 #define Xorriso_header_version_minoR  6
-#define Xorriso_header_version_micrO  4
+#define Xorriso_header_version_micrO  6
 
 
 /** Eventually something like ".pl01" to indicate a bug fix. Normally empty.
@@ -197,7 +197,9 @@ int Xorriso_startup_libraries(struct XorrisO *xorriso, int flag);
 
 /* Inquire whether option -commit would make sense.
    @param xorriso The context object to inquire.
-   @param flag    unused yet, submit 0
+   @param flag    @since 0.6.6
+                  bit0= do not return 1 if -as mkisofs -print-size was
+                        performed on the current image.
    @return        0= -commit would have nothing to do
                   1= a new image session would emerge at -commit
 */
@@ -765,6 +767,10 @@ int Xorriso_option_disk_dev_ino(struct XorrisO *xorriso, char *mode, int flag);
 /* Option -disk_pattern "on"|"ls"|"off" */
 int Xorriso_option_disk_pattern(struct XorrisO *xorriso, char *mode, int flag);
 
+/* Option -displacement [-]offset */
+int Xorriso_option_displacement(struct XorrisO *xorriso, char *value,
+                                int flag);
+
 /* Option -drive_class */
 int Xorriso_option_drive_class(struct XorrisO *xorriso,
                                char *d_class, char *pattern, int flag);
